summaryrefslogtreecommitdiffstats
path: root/ktouch/src/ktouchstatus.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:58:43 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:58:43 -0600
commit2d7b541a4e0095d40e37aaefbf9c4a9b9d149302 (patch)
tree628c1676b27475e583cfd0c2105bb41b646654bf /ktouch/src/ktouchstatus.h
parent6c3f7a55fb7888efc80a7350ef0c2f46ee02baa3 (diff)
downloadtdeedu-2d7b541a4e0095d40e37aaefbf9c4a9b9d149302.tar.gz
tdeedu-2d7b541a4e0095d40e37aaefbf9c4a9b9d149302.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 6c3f7a55fb7888efc80a7350ef0c2f46ee02baa3.
Diffstat (limited to 'ktouch/src/ktouchstatus.h')
-rw-r--r--ktouch/src/ktouchstatus.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/ktouch/src/ktouchstatus.h b/ktouch/src/ktouchstatus.h
index f4be66f4..229ed903 100644
--- a/ktouch/src/ktouchstatus.h
+++ b/ktouch/src/ktouchstatus.h
@@ -22,21 +22,21 @@
/** This is the implementation of the status widget (at the top of the main view).
* It simply displays the status but does not have a functionality of its own.
* Everythings is calculated in the trainer (see KTouchTrainer)and then displayed
* using the updateStatus() member function.
* The "new characters" string is set using the member function setNewChars().
*/
-class KTouchStatus : public KTouchStatusLayout {
+class KTouchtqStatus : public KTouchStatusLayout {
Q_OBJECT
TQ_OBJECT
public:
/// Constructor
- KTouchStatus(TQWidget *parent);
+ KTouchtqStatus(TQWidget *parent);
/// Called when the preferences have changed in the configuration dialog.
void applyPreferences();
/// Sets the new characters text.
void setNewChars(const TQString& newChars);
/// Updates the level LCD and the correctness progress bar
- void updateStatus(unsigned int level, double correctness);
+ void updatetqStatus(unsigned int level, double correctness);
};
#endif // KTOUCHSTATUS_H
@@ -22,21 +22,21 @@
* It simply displays the status but does not have a functionality of its own.
* Everythings is calculated in the trainer (see KTouchTrainer)and then displayed
- * using the updateStatus() member function.
+ * using the updatetqStatus() member function.
* The "new characters" string is set using the member function setNewChars().
*/